# Changelog

## 1.0.0

- Added tests, CI workflows and hatchling/ trusted publishing and `--version` option
  [@jensens, 2025-11-03]
- Initial porting from https://github.com/rnixx/githelper
  [@rnix, 2025-03-03]
